@@ -11,10 +11,10 @@
 #
 ###################################################################
 
-__version__ = "1.0.14"
+__version__ = "1.0.16"
 __author__ = "Frederick Stallmeyer <fraizy@gmx.de>"
 __license__ = "MIT"
 
-from .klyqa_ctl import *
-from .general import *
-from .devices.device import format_uid
+from klyqa_ctl.klyqa_ctl import *
+from klyqa_ctl.general import *
+from klyqa_ctl.devices.device import format_uid
