@@ -34,7 +34,7 @@ import logging
 import time
 from typing import TypeVar, Any, Type
 
-from .general.parameters import get_description_parser
+from klyqa_ctl.general.parameters import get_description_parser
 
 
 NoneType: Type[None] = type(None)
